SvgImageKey class

Annotations

Constructors

SvgImageKey({required String path, required int pixelWidth, required int pixelHeight, required double scale, required SvgSource source, Map<String, String>? httpHeaders, Color? color, SvgStringGetter? svgGetter})
const

Properties

color Color?
Color to tint the SVG
final
hashCode int
The hash code for this object.
no setteroverride
httpHeaders Map<String, String>?
Http headers to access network svg Only for network svg
final
path String
Path to svg asset.
final
pixelHeight int
Height in physical pixels. Used when raterizing.
final
pixelWidth int
Width in physical pixels. Used when raterizing.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
Used to calculate logical size from physical, i.e. logicalWidth = pixelWidth / scale, logicalHeight = pixelHeight / scale. Should be equal to MediaQueryData.devicePixelRatio.
final
source SvgSource
Image source.
final
svgGetter SvgStringGetter?
Svg string getter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override