Svg class
Rasterizes given svg picture for displaying in Image widget:
Image(
width: 32,
height: 32,
image: Svg('assets/my_icon.svg'),
)
- Inheritance
Constructors
-
Svg(String path, {Size? size, double? scale, Color? color, SvgSource source = SvgSource.asset, Map<
String, String> ? httpHeaders, SvgStringGetter? svgGetter}) -
Width and height can also be specified from Image constructor.
Default size is 100x100 logical pixels.
Different size can be specified in Image parameters
const
Properties
- color → Color?
-
Color to tint the SVG
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
httpHeaders
→ Map<
String, String> ? -
Http headers to access network svg
Only for network svg
final
- path → String
-
Path to svg file or asset
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double?
-
Image scale.
final
- size → Size?
-
Size in logical pixels to render.
Useful for DecorationImage.
If not specified, will use size from Image.
If Image not specifies size too, will use default size 100x100.
final
- source → SvgSource
-
Source of svg image
final
- svgGetter → SvgStringGetter?
-
Get svg string.
Override the default get method.
When returning null, use the default method.
final
Methods
-
createStream(
ImageConfiguration configuration) → ImageStream -
Called by resolve to create the ImageStream it returns.
inherited
-
evict(
{ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) → Future< bool> -
Evicts an entry from the image cache.
inherited
-
loadBuffer(
SvgImageKey key, DecoderBufferCallback decode) → ImageStreamCompleter -
Converts a key into an ImageStreamCompleter, and begins fetching the
image.
inherited
-
loadImage(
SvgImageKey key, ImageDecoderCallback decode) → ImageStreamCompleter -
Converts a key into an ImageStreamCompleter, and begins fetching the
image.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
obtainCacheStatus(
{required ImageConfiguration configuration, ImageErrorListener? handleError}) → Future< ImageCacheStatus?> -
Returns the cache location for the key that this ImageProvider creates.
inherited
-
obtainKey(
ImageConfiguration configuration) → Future< SvgImageKey> -
Converts an ImageProvider's settings plus an ImageConfiguration to a key
that describes the precise image to load.
override
-
resolve(
ImageConfiguration configuration) → ImageStream -
Resolves this image provider using the given
configuration, returning an ImageStream.inherited -
resolveStreamForKey(
ImageConfiguration configuration, ImageStream stream, SvgImageKey key, ImageErrorListener handleError) → void -
Called by resolve with the key returned by obtainKey.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getFilterColor(
dynamic color) → Color